/*
 * Licensed Materials - Property of IBM
 *
 * com.ibm.etools.c
 *
 *  Copyright IBM Corporation 2004. All Rights Reserved. 
 *
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.etools.c.importer;

import org.eclipse.core.runtime.ILog;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;

import com.ibm.etools.c.messages.Messages;
import com.ibm.etools.c.plugin.CPlugin;

/**
 * The CResource class handles the resources for this package.
 */
public class CResource {

    public static final String copyright = "Licensed Material - Property of IBM\n com.ibm.etools.c\n(C) Copyright IBM Corp. 2004 - All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; //$NON-NLS-1$

    /**
     * This method writes a message to the log file.
     * 
     * @param aMessage
     *            The text to be logged.
     */
    public static void writeLog(String aMessage) {

        String logMessage = "";

        if (aMessage != null) {
            logMessage = logMessage.concat("message: ");
            logMessage = logMessage.concat(aMessage);
            logMessage = logMessage.concat(" ");
        }

        // Create the IStatus log record
        IStatus status = new Status(IStatus.ERROR, CPlugin.PLUGIN_ID, IStatus.OK, logMessage, null);

        // Retrieve the plug-in's ILog
        ILog logger = CPlugin.getDefault().getLog();

        //Log the IStatus log record to the plug-in's ILog
        logger.log(status);
    }

    /**
     * This method writes a message to the log file.
     */
    public static void writeLog(Object msgSource, String methodName, String aMessage) {

        String logMessage = "";

        if (msgSource != null) {
            logMessage = logMessage.concat("msgSource: ");
            logMessage = logMessage.concat(msgSource.toString());
            logMessage = logMessage.concat(" ");
        }

        if (methodName != null) {
            logMessage = logMessage.concat("methodName: ");
            logMessage = logMessage.concat(methodName);
            logMessage = logMessage.concat(" ");
        }

        if (aMessage != null) {
            logMessage = logMessage.concat("message: ");
            logMessage = logMessage.concat(aMessage);
            logMessage = logMessage.concat(" ");
        }

        // Create the IStatus log record
        IStatus status = new Status(IStatus.ERROR, CPlugin.PLUGIN_ID, IStatus.OK, logMessage, null);

        // Retrieve the plug-in's ILog
        ILog logger = CPlugin.getDefault().getLog();

        //Log the IStatus log record to the plug-in's ILog
        logger.log(status);
    }

    /**
     * This method writes a message to the log file.
     */
    public static void writeLog(Object msgSource, String methodName, Throwable throwable) {

        String logMessage = "";

        if (msgSource != null) {
            logMessage = logMessage.concat("msgSource: ");
            logMessage = logMessage.concat(msgSource.toString());
            logMessage = logMessage.concat(" ");
        }

        if (methodName != null) {
            logMessage = logMessage.concat("methodName: ");
            logMessage = logMessage.concat(methodName);
            logMessage = logMessage.concat(" ");
        }

        if (throwable != null) {
            logMessage = logMessage.concat("throwable: ");
            logMessage = logMessage.concat(throwable.getMessage());
            logMessage = logMessage.concat(" ");
        }

        // Create the IStatus log record
        IStatus status = new Status(IStatus.ERROR, CPlugin.PLUGIN_ID, IStatus.OK, logMessage, throwable);

        // Retrieve the plug-in's ILog
        ILog logger = CPlugin.getDefault().getLog();

        //Log the IStatus log record to the plug-in's ILog
        logger.log(status);
    }

    /**
     * This method writes a message to the log file.
     */
    public static void writeLog(Object msgSource, String methodName, int severity, String aMessage) {

        String logMessage = "";

        if (msgSource != null) {
            logMessage = logMessage.concat("msgSource: ");
            logMessage = logMessage.concat(msgSource.toString());
            logMessage = logMessage.concat(" ");
        }

        if (methodName != null) {
            logMessage = logMessage.concat("methodName: ");
            logMessage = logMessage.concat(methodName);
            logMessage = logMessage.concat(" ");
        }

        if (aMessage != null) {
            logMessage = logMessage.concat("message: ");
            logMessage = logMessage.concat(aMessage);
            logMessage = logMessage.concat(" ");
        }

        // Create the IStatus log record
        IStatus status = new Status(severity, CPlugin.PLUGIN_ID, IStatus.OK, logMessage, null);

        // Retrieve the plug-in's ILog
        ILog logger = CPlugin.getDefault().getLog();

        //Log the IStatus log record to the plug-in's ILog
        logger.log(status);
    }

    /**
     * This method returns the localized string associated to the parameter.
     * 
     * @param key
     *            The key used to search for the localized message.
     * @return The localized string.
     */
    public static String getString(String key) {
        return Messages.getString(key);
    }

    /**
     * This method returns the localized string modified with the array of
     * objects.
     * 
     * @param key
     *            The key used to search for the localized message.
     * @param args
     *            The array of objects that are to be incorporated into the
     *            localized string.
     * @return The localized string text.
     */
    public static String getString(String key, Object[] args) {
        return Messages.getString(key, args);
    }

    /**
     * This method returns the localized string modified with one string
     * argument.
     */
    public static String getString(String key, String args) {
        Object[] obj = { args };
        return getString(key, obj);
    }

    /**
     * This method returns the localized string modified with two string
     * arguments
     */
    public static String getString(String key, String args1, String args2) {
        Object[] obj = { args1, args2 };
        return getString(key, obj);
    }

}