/*
 * Licensed Materials - Property of IBM
 *
 * com.ibm.etools.c
 *
 *  Copyright IBM Corporation 2004. All Rights Reserved. 
 *
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.etools.c.messages;

import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * Methods returning the message string of a resource bundle
 * 
 * @author Bernhard Jakob, IBM
 */
public class Messages {

    public static final String copyright = "Licensed Material - Property of IBM\n com.ibm.etools.c\n(C) Copyright IBM Corp. 2004 - All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; //$NON-NLS-1$

    private static final String BUNDLE_NAME = "com.ibm.etools.c.messages.messages"; //$NON-NLS-1$

    private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(BUNDLE_NAME);

    private Messages() {
    }

    public static String getString(String key) {
        try {
            return RESOURCE_BUNDLE.getString(key);
        } catch (MissingResourceException e) {
            return '!' + key + '!';
        }
    }

    /**
     * Retrieves a message with one parameter from the catalog. This is just a
     * convenience wrapper for {@link #get(String,Object[])}.
     * 
     * @param key
     *            The key of the message to retrieve.
     * @param var
     *            The substitution variable to use.
     * @return The message text or <code>null</code>, if the key cannot be
     *         found.
     */
    public static String getString(String key, Object var) {
        return getString(key, new Object[] { var });
    }

    /**
     * Retrieves a message with an arbitrary number of parameters from the
     * catalog.
     * <ul>
     * <li>If you specify less variables than there are parameters, the
     * placeholders for the missing parameters will be left as-is. This is also
     * true if you omit the variables at all using {@link #get(String)}.</li>
     * <li>If you specify a <code>null</code> variable, the corresponding
     * placeholder will be replaced with the string <code>null</code>.</li>
     * <li>If you specify any variables at all when retrieving a message (it
     * does not matter if they are actually used or not), you must escape the
     * single quote character by doubling it in the message string. In contrast,
     * if you don't specify any variables by using the {@link #get(String)}
     * method (again, it does not matter if they are actually used), you must
     * not escape the single quote character.</li>
     * </ul>
     * 
     * @param key
     *            The key of the message to retrieve.
     * @param vars
     *            The list of substitution variables to use.
     * @return The message text or <code>null</code>, if the key cannot be
     *         found.
     */
    public static String getString(String key, Object[] vars) {
        String text = getString(key);
        return text == null ? null : MessageFormat.format(text, vars);
    }
}