// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<com.ibm.etools.cobol.preference.ui>>
//   (C) Copyright IBM Corp. 2002,2004 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************
package com.ibm.etools.cobol.preference.ui.common;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Vector;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.DialogPage;
import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ColumnWeightData;
import org.eclipse.jface.viewers.ComboBoxCellEditor;
import org.eclipse.jface.viewers.ICellModifier;
import org.eclipse.jface.viewers.IContentProvider;
import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.TableLayout;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.viewers.TextCellEditor;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.window.Window;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.TabFolder;
import org.eclipse.swt.widgets.TabItem;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.swt.widgets.TableItem;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.help.WorkbenchHelp;

import com.ibm.etools.cobol.importer.COBOLLocaleRelatedConstants;
import com.ibm.etools.cobol.importer.CobolPreferenceStore;
import com.ibm.etools.cobol.importer.ICobolPreferenceConstants;
import com.ibm.etools.cobol.preference.ui.plugin.CobolPreferenceUIPlugin;
import com.ibm.etools.cobol.preference.ui.preferencepage.CobolPreferencePage;
import com.ibm.etools.cobol.preference.ui.typeimport.CobolImporterPropertiesPage;

/**
 * This class is responsible for creating the controls used by 
 * CobolImporterProperties and CobolPreferences pages.
 */
public class CobolPropertiesPage
	implements SelectionListener, ModifyListener, ICobolUIPreferenceConstants 
{
	private static final String copyright = "Licensed Material - Property of IBM <<PART NUMBER - 5724-D15>> (C) Copyright IBM Corp. 2003 - All Rights Reserved. US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.".intern(); //$NON-NLS-1$


	// controls
	private Composite main; 
	
	public Combo comboPS;
	public Combo comboLC;
	public Combo comboACP;
	public Combo comboEL;
	
	
	public Text textCP;
	public Text textCurrency;
	public Button buttonCPSelect;	//@P1a
	public Combo comboFPF;
	public Button radioEBig;
	public Button radioELittle;
	public Button radioRIEBig;
	public Button radioRIELittle;
	public Button radioASCII;
	public Button radioEBCDIC;
	public Button radioEBCDICC;
	public Text textHostCP;
	public Button buttonHostCPSelect;	
	public Button radioCOSTD;
	public Button radioCOOPT;
	public Button radioCOBIN;
	//public Button radioNPPFD;
	//public Button radioNPNOPFD;
	//public Button radioNPMIG;
	public Button radioNSDBCS;
	public Button radioNSNATIONAL;
	public Button radioASINGLE;
	public Button radioADOUBLE;
	public Button radioCSLOCALE;
	public Button radioCSEBCDIC;
	public Button radioCSBIN;	
	public Button radioNCSLOCALE;
	public Button radioNCSBIN;	
	
	public Button checkBoxCur;
	public Button checkBoxSOSI;	
	
	private Button _editBtn;
	
	public TableViewer tableViewer;
	private MyTableElement[] tableElements;	
	
	private final ArrayList platform_selection_values = new ArrayList(4);
	private final ArrayList floating_pt_values = new ArrayList(2);
	private final HashMap endian_values = new HashMap(2);
	private final HashMap remote_int_endian_values = new HashMap(2);
	private final HashMap extra_decimal_sign_values = new HashMap(3);	
	private final HashMap quote_values = new HashMap(2);	
	private final HashMap trunc_values = new HashMap(2);
	private final HashMap nsymbol_values = new HashMap(2);	
	private final HashMap collseq_values = new HashMap(3);
	private final HashMap ncollseq_values = new HashMap(2);
	
	private final String[] COLUMNS = { "STRING", "COMBO" };
	private final String[] VALUES = {CobolPreferenceUIPlugin.getResource("%EXTENSION_SUPPORT_VALUE1"), CobolPreferenceUIPlugin.getResource("%EXTENSION_SUPPORT_VALUE2")};

	private DialogPage parentPage;	
	private COBOLLocaleRelatedConstants clrc;

	private String hostCodePageValue;	

	private class CBETableElement {
		private String text;
		private String value;
		private String originalValue;
		private String defaultValue;
		private boolean useDefaultValue;
		private boolean isUserModified = false;
		
		public CBETableElement(String text, String value, String defaultValue, boolean useDefaultValue) {
			super();
			
			setText(text);
			setValue(value);

			this.originalValue = value;
			this.defaultValue = defaultValue;
			this.useDefaultValue = useDefaultValue;
		}
		public String getDefaultValue() {
			return defaultValue;
		}
		public void setDefaultValue(String defaultValue) {
			this.defaultValue = defaultValue;
		}
		public boolean isUserModified() {
			return isUserModified;
		}
		public void setUserModified(boolean isUserModified) {
			this.isUserModified = isUserModified;
		}
		public String getOriginalValue() {
			return originalValue;
		}
		public void setOriginalValue(String originalValue) {
			this.originalValue = originalValue;
		}
		public String getText() {
			return text;
		}
		public void setText(String text) {
			this.text = text;
		}
		public boolean isUseDefaultValue() {
			return useDefaultValue;
		}
		public void setUseDefaultValue(boolean useDefaultValue) {
			this.useDefaultValue = useDefaultValue;
		}
		public String getValue() {
			return value;
		}
		public void setValue(String value) {
			this.value = value;
		}
		public boolean isAffected() {
			return isUseDefaultValue();
		}
		public String toString() {
			return "<text=\""
				+ text
				+ "\" value=\""
				+ value
				+ "\" originalValue=\""
				+ originalValue
				+ "\" defaultValue=\""
				+ defaultValue
				+ "\"/>";
		}
	}
	
	private class EditDialog extends Dialog{
		private String _extension;
		private String _support;
		private Text _extensionText;
		private Text _supportText;
		private Combo _supportCombo;
		private String _title;

		public EditDialog(Shell shell,String title,String extension,String support) {
			super(shell);

			if (extension != null)
				_extension = extension;
			_support = support;
			_title = title;
		}

		protected void configureShell(Shell shell) {
			super.configureShell(shell);
			shell.setText(_title);
		}

		public void extension(String extension) {
			_extension = extension;
		}

		public String extension() {
			return _extension;
		}

		public void support(String support) {
			_support = support;
		}

		public String support() {
			return _support;
		}
	
		protected Control createDialogArea(Composite parent) {
			Composite result = (Composite) super.createDialogArea(parent);

			GridLayout layout;
			GridData data;
			Label label;

			layout = new GridLayout();
			layout.numColumns = 2;
			result.setLayout(layout);
			data = GridUtil.createFill();
			data.widthHint = 400;
			result.setLayoutData(data);

			label = new Label(result, SWT.NULL);
			label.setText(CobolPreferenceUIPlugin.getResource("%EXTENSION_COLUMN_LABEL"));
			_extensionText = new Text(result, SWT.BORDER);
			_extensionText.setLayoutData(GridUtil.createHorizontalFill());
			_extensionText.setEditable(false);
	
			label = new Label(result, SWT.NULL);
			label.setText(CobolPreferenceUIPlugin.getResource("%EXTENSION_SUPPORT_LABEL"));
			_supportCombo = new Combo(result, SWT.BORDER | SWT.READ_ONLY);
			_supportCombo.setLayoutData(GridUtil.createHorizontalFill());

			for (int i=0;i<VALUES.length;i++)
				_supportCombo.add(VALUES[i]);
				
			if (_extension != null)
				_extensionText.setText(_extension);
			if (_support != null)
				_supportCombo.setText(_support);

			_supportCombo.setFocus();
			return result;
		}

		protected void okPressed() {
			_extension = _extensionText.getText().trim();
			_support = _supportCombo.getText();
			super.okPressed();
		}

	}
	
	private class MyTableElement extends CBETableElement {
		private String text;
		private String value;
		public MyTableElement(String text, String value) {
			super(text, value, "", false);
			setText(text);
			setValue(value);
		}
		public String getText() {
			return text;
		}
		public void setText(String text) {
			this.text = text;
		}
		public String getValue() {
			return value;
		}
		public void setValue(String value) {
			this.value = value;
		}
	}	
	
	private class PreferenceContentProvider implements IStructuredContentProvider {
		/**
		 * @see IStructuredContentProvider#getElements(Object)
		 */
		public Object[] getElements(Object element) {
			if (element instanceof MyTableElement[])
				return (MyTableElement[]) element;

			return new Object[0];
		}
		/**
		 * @see IContentProvider#dispose()
		 */
		public void dispose(){
		}
		/**
		 * @see IContentProvider#inputChanged(Viewer, Object, Object)
		 */
		public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
		}
	}

	private class PreferenceLabelProvider
	extends LabelProvider
	implements ITableLabelProvider {
	/**
	 * @see ITableLabelProvider#getColumnImage(Object, int)
	 */
		public Image getColumnImage(Object element, int columnIndex) {
			return null;
		}
		/**
		 * @see ITableLabelProvider#getColumnText(Object, int)
		 */
		public String getColumnText(Object element, int columnIndex) {
			if (element instanceof MyTableElement) {
				MyTableElement myTableElement = (MyTableElement) element;
	
				if (columnIndex == 0)
					return myTableElement.getText();
	
				if (columnIndex == 1)
					return myTableElement.getValue();
			}
			return "";
		}
	}
	private class PreferenceCellModifier implements ICellModifier {
		private Viewer viewer;

		public PreferenceCellModifier(Viewer viewer) {
			this.viewer = viewer;
		}
		/**
		 * @see ICellModifier#canModify(Object, String)
		 */
		public boolean canModify(Object element, String property) {
			if (element instanceof MyTableElement) {
				MyTableElement myTableElement = (MyTableElement) element;
				if (property.equals(COLUMNS[0]))
					return false;

				if (property.equals(COLUMNS[1]))
					return true;
			}
			return false;
		}
		/**
		 * @see ICellModifier#getValue(Object, String)
		 */
		public Object getValue(Object element, String property) {
			if (element instanceof MyTableElement) {
				MyTableElement myTableElement = (MyTableElement) element;

				if (property.equals(COLUMNS[0]))
					return myTableElement.getText();

				if (property.equals(COLUMNS[1]))
					return getValueIndex(myTableElement.getValue());
			}
			return null;
		}
		/**
		 * @see ICellModifier#modify(Object, String, Object)
		 */
		public void modify(Object element, String property, Object value) {
			if (element instanceof TableItem) {
				Object myElement = ((TableItem) element).getData();

				if (myElement instanceof MyTableElement) {
					MyTableElement myTableElement = (MyTableElement) myElement;

					if (property.equals(COLUMNS[0]))
						myTableElement.setText((String) value);

					if (property.equals(COLUMNS[1])) {
						
						String stringValue = getValue((Integer) value);
						if (stringValue != null)
						{
							myTableElement.setValue(stringValue);
						}
					}
					viewer.refresh();
				}
			}
		}
		private Integer getValueIndex(String value) {
			for (int i = 0, length = VALUES.length; i < length; i++) {
				if (VALUES[i].equals(value))
					return new Integer(i);
			}
			return new Integer(0);
		}
		private String getValue(Integer index) {
			if (index != null) {
				int idx = index.intValue();
				if ((idx >= 0) && (idx < VALUES.length))
					return VALUES[idx];
			}
			return null;
		}
	}
	
	public CobolPropertiesPage(DialogPage page) {
		super();
		parentPage = page;
		clrc = new COBOLLocaleRelatedConstants();
	}

	public Text getCodePageField() {
		return textCP;
	}

	/**
	 * Creates preference page controls on demand.
	 */
	public Control createContents(Composite parent) {

		main = createComposite(parent,1,true);

		createTabControl(main);
						
		main.pack(true);
		main.layout(true);

		// Initialize the values for the preference store
		initializePreferenceStoreValues();

		// obtain the values from the Preference Store
		initializeValues();

		return main;
	}

    /**
     * 
     * Utility method that creates the TabControl for the COBOL properties
     * 
     * @param Composite
     *  
     */
    private void createTabControl(Composite parent) {

        TabFolder folder = new TabFolder(parent, SWT.NONE);

        GridData data = new GridData();
        data.verticalAlignment = GridData.FILL;
        data.horizontalAlignment = GridData.FILL;
        data.grabExcessHorizontalSpace = true;
        data.grabExcessVerticalSpace = true;
        folder.setLayoutData(data);

        TabItem item;

        item = new TabItem(folder, SWT.NONE);
        item.setText(CobolPreferenceUIPlugin.getResource("%TAB1_LABEL"));
        item.setControl(createPage1Contents(folder));

        item = new TabItem(folder, SWT.NONE);
        item.setText(CobolPreferenceUIPlugin.getResource("%TAB2_LABEL"));
        item.setControl(createPage2Contents(folder));

        return;
    }	
    /**
     * 
     * Utility method that creates the controls on the first tab of the COBOL
     * properties
     * 
     * @param Compostite            
     * 
     * @return Control - the newly-created composite
     *  
     */
    public Control createPage1Contents(Composite parent) {

        Composite main = createComposite(parent, 1, false);

		Composite labelComp = createComposite(main, 1, false);			
		GridLayout layout = new GridLayout();
		layout.marginHeight = 1;
		labelComp.setLayout(layout);
		Label lb = new Label(labelComp,SWT.NONE);
		lb.setText(CobolPreferenceUIPlugin.getResource("%SPECIFY_TARGET_PLATFORM_PROPERTIES"));
        
		Composite platformComp = createComposite(main, 2, false);
		comboPS = createCombo(platformComp, CobolPreferenceUIPlugin.getResource("%PLATFORM_SELECTION_LABEL"));
		
		Composite codePageComp = createComposite(main, 3, false);
		textCP = createText(codePageComp, CobolPreferenceUIPlugin.getResource("%CODE_PAGE_SELECT_HEADER"));
		buttonCPSelect = createPushButton(codePageComp, CobolPreferenceUIPlugin.getResource("%SELECT_BUTTON"));

		Composite floatingPtComp = createComposite(main, 2, false);
		comboFPF = createCombo(floatingPtComp, CobolPreferenceUIPlugin.getResource("%FLOATING_POINT_FORMAT_LABEL"));
		
		Composite endianComp = createComposite(main, 2, false);
		createEndianGroup(endianComp);
		createRemoteEndianGroup(endianComp);

		createExtDecimalGroup(main);
		
		Composite labelComp1 = createComposite(main, 1, false);			
		GridLayout layout1 = new GridLayout();
		layout1.marginHeight = 1;
		labelComp1.setLayout(layout1);
		Label lbl = new Label(labelComp1,SWT.NONE);
		lbl.setText(CobolPreferenceUIPlugin.getResource("%SPECIFY_COMPILE_OPTIONS"));
	
		createQuoteGroup(main);
		createTruncGroup(main);
		createNSymbolGroup(main);
		
		return main;
    }
    /**
     * 
     * Utility method that creates the controls on the first tab of the COBOL
     * properties
     * 
     * @param Compostite            
     * 
     * @return Control - the newly-created composite
     *  
     */
    public Control createPage2Contents(Composite parent) {

        Composite main = createComposite(parent, 1, false);
        
		Composite labelComp = createComposite(main, 1, false);			
		GridLayout layout = new GridLayout();
		layout.marginHeight = 10;
		labelComp.setLayout(layout);
		Label lbl = new Label(labelComp,SWT.NONE);
		lbl.setText(CobolPreferenceUIPlugin.getResource("%SPECIFY_COMPILE_OPTIONS"));


		Composite localeNameComp = createComposite(main, 2, false);
		comboLC = createCombo(localeNameComp, CobolPreferenceUIPlugin.getResource("%COMPILE_TIME_LOCALE_LABEL"));
		
		Composite asciiColdePagesComp = createComposite(main, 2, false);
		comboACP = createCombo(asciiColdePagesComp, CobolPreferenceUIPlugin.getResource("%ASCII_CODEPAGE_LABEL"));

		Composite errorMsgsLanguageComp = createComposite(main, 2, false);
		comboEL = createCombo(errorMsgsLanguageComp, CobolPreferenceUIPlugin.getResource("%ERROR_MESSAGES_LANGUAGE"));
		
		Composite currencyComp = createComposite(main, 2, false);
		textCurrency = createText(currencyComp, CobolPreferenceUIPlugin.getResource("%CURRENCY_LABEL"));
		textCurrency.setTextLimit(5);

		Composite composite = new Composite(main, SWT.NONE);
		GridLayout layout2 = new GridLayout();
		layout2.numColumns = 1;		
		layout2.marginHeight = 0;
		composite.setLayout(layout2);
		Label lb2 = new Label(composite,SWT.NONE);
		lb2.setText(CobolPreferenceUIPlugin.getResource("%CURRENCY_EXAMPLE_LABEL"));
		
		Composite sosiComp = createComposite(main, 2, false);
		checkBoxSOSI = createCheckboxButton(sosiComp, CobolPreferenceUIPlugin.getResource("%SOSI_LABEL"));
		
		createCOLLSEQGroup(main);
		createNCOLLSEQGroup(main);		

		Composite labelComp3 = createComposite(main, 1, false);			
		GridLayout layout3 = new GridLayout();
		layout3.marginHeight = 10;
		labelComp3.setLayout(layout3);
		Label lb3 = new Label(labelComp3,SWT.NONE);
		lb3.setText(CobolPreferenceUIPlugin.getResource("%FILE_EXTENSION_SUPPORT"));
		
		createFileExtensionTable(main);
		
		return main;

    }


	/**
	 * Creates composite control and sets the default layout data.
	 *
	 * @param parent  the parent of the new composite
	 * @param numColumns  the number of columns for the new composite
	 * @param bGrabExcessVert - set the GridData's grabExcessVerticalSpace flag
	 * @return the newly-created coposite
	 */
	private Composite createComposite(Composite parent, int numColumns, boolean bGrabExcessVert) {

		Composite composite = new Composite(parent, SWT.NONE);

		//GridLayout
		GridLayout layout = new GridLayout();
		layout.numColumns = numColumns;
		layout.marginHeight = 5;
		layout.marginWidth = 5;
		composite.setLayout(layout);

		//GridData
		GridData data = new GridData();
		data.verticalAlignment = GridData.FILL;
		data.horizontalAlignment = GridData.FILL;
		data.grabExcessHorizontalSpace = true;
		if (bGrabExcessVert) 
			data.grabExcessVerticalSpace = true;
			
		composite.setLayoutData(data);

		return composite;
	}

	/**
	 * Creates Group control and sets the default layout data.
	 *
	 * @param parent  the parent of the new group
	 * @param numColumns  the number of columns for the new group
	 * @param label  the label for the new Group
	 * @return the newly-created group
	 */
	private Group createGroup(Composite parent, int numColumns, String label) {

		Group composite = new Group(parent, SWT.NONE);

		//GridLayout
		GridLayout layout = new GridLayout();
		layout.numColumns = numColumns;
		composite.setLayout(layout);

		//GridData
		GridData data = new GridData();
		data.verticalAlignment = GridData.FILL;
		data.horizontalAlignment = GridData.FILL;
		data.grabExcessHorizontalSpace = true;
		composite.setLayoutData(data);

		composite.setText(label);

		return composite;
	}

	/**
	 * Utility method that creates a combo box instance
	 * and sets the default layout data.
	 *
	 * @param parent  the parent for the new combo
	 * @param label  the label for the new combo
	 * @return the newly-created combo
	 */
	private Combo createCombo(Composite parent, String label) {
		Label lbl = new Label(parent,SWT.NONE);
		lbl.setText(label);

		Combo combo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
		combo.setLayout(new GridLayout());
		GridData gd = new GridData(GridData.GRAB_HORIZONTAL | GridData.HORIZONTAL_ALIGN_FILL);
		combo.setLayoutData(gd);
		combo.addSelectionListener(this);
		return combo;
	}

	/**
	 * Utility method that creates a text control instance
	 * and sets the default layout data.
	 *
	 * @param parent  the parent for the new text
	 * @param label  the label for the new text
	 * @return the newly-created text
	 */
	private Text createText(Composite parent, String label) {

		Label lbl = new Label(parent,SWT.NONE);
		lbl.setText(label);

		Text textField = new Text(parent, SWT.SINGLE | SWT.BORDER);
		GridData gd = new GridData(GridData.GRAB_HORIZONTAL | GridData.HORIZONTAL_ALIGN_FILL);
		textField.setLayoutData(gd);
		textField.addSelectionListener(this);
		textField.addModifyListener(this);
		return textField;
	}

	/**
	 * Utility method that creates a push button instance
	 * and sets the default layout data.
	 *
	 * @param parent  the parent for the new button
	 * @param label  the label for the new button
	 * @return the newly-created button
	 */
	private Button createPushButton(Composite parent, String label) {
		Button button = new Button(parent, SWT.PUSH);
		button.setText(label);
		button.addSelectionListener(this);
		GridData data = new GridData();
		data.horizontalAlignment = GridData.FILL;
		button.setLayoutData(data);
		return button;
	}

	/**
	 * Utility method that creates a radio button instance
	 * and sets the default layout data.
	 *
	 * @param parent  the parent for the new button
	 * @param label  the label for the new button
	 * @return the newly-created button
	 */
	private Button createRadioButton(Composite parent, String label) {
		Button button = new Button(parent, SWT.RADIO);
		button.setText(label);
		button.addSelectionListener(this);
		GridData data = new GridData();
		data.horizontalAlignment = GridData.FILL;
		button.setLayoutData(data);
		return button;
	}

	/**
	 * Utility method that creates a checkbox button instance
	 * and sets the default layout data.
	 *
	 * @param parent  the parent for the new button
	 * @param label  the label for the new button
	 * @return the newly-created button
	 */
	private Button createCheckboxButton(Composite parent, String label) {
		Button button = new Button(parent, SWT.CHECK);
		button.setText(label);
		button.addSelectionListener(this);
		GridData data = new GridData();
		data.horizontalAlignment = GridData.FILL;
		button.setLayoutData(data);
		return button;
	}
	
	private void createEndianGroup(Composite parent) {
		Composite group = createGroup(parent, 2, CobolPreferenceUIPlugin.getResource("%ENDIAN_LABEL"));
		radioELittle = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%LITTLE_ENDIAN_VALUE"));
		radioEBig = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%BIG_ENDIAN_VALUE"));
		return;
	}
	
	private void createRemoteEndianGroup(Composite parent) {
		Composite group = createGroup(parent, 2, CobolPreferenceUIPlugin.getResource("%REMOTE_INTEGER_ENDIAN_LABEL"));
		radioRIELittle = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%LITTLE_ENDIAN_VALUE"));
		radioRIEBig = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%BIG_ENDIAN_VALUE"));
		return;
	}
	
	private void createExtDecimalGroup(Composite parent) {
		Composite group = createGroup(parent, 1, CobolPreferenceUIPlugin.getResource("%EXTERNAL_DECIMAL_SIGN_LABEL"));
		radioASCII = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%ASCII_ENCODING_VALUE"));
		radioEBCDIC = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%EBCDIC_ENCODING_VALUE"));
		radioEBCDICC = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%EBCDIC_CUSTOM_ENCODING_VALUE"));
		Composite codePageComp = createComposite(group, 4, false);
		Label label = new Label(codePageComp,SWT.NONE);
		label.setText("  ");
		textHostCP = createText(codePageComp, CobolPreferenceUIPlugin.getResource("%HOST_CODE_PAGE_SELECT_HEADER"));
		buttonHostCPSelect = createPushButton(codePageComp, CobolPreferenceUIPlugin.getResource("%SELECT_BUTTON2"));		
		return;
	}
	
	private void createQuoteGroup(Composite parent) {
		Composite group = createGroup(parent, 2, CobolPreferenceUIPlugin.getResource("%QUOTE_LABEL"));
		radioADOUBLE = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%DOUBLE_VALUE"));
		radioASINGLE = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%SINGLE_VALUE"));
		return;
	}

	private void createTruncGroup(Composite parent) {
		Composite group = createGroup(parent, 3, CobolPreferenceUIPlugin.getResource("%TRUNC_LABEL"));
		radioCOSTD = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%STD_VALUE"));
		radioCOOPT = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%OPT_VALUE"));
		radioCOBIN = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%BIN_VALUE"));
		return;
	}	

	private void createNSymbolGroup(Composite parent) {
		Composite group = createGroup(parent, 2, CobolPreferenceUIPlugin.getResource("%NSYMBOL_LABEL"));
		radioNSNATIONAL = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%NATIONAL_VALUE"));
		radioNSDBCS = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%DBCS_VALUE"));		
		return;
	}

	private void createCOLLSEQGroup(Composite parent) {
		Composite group = createGroup(parent, 3, CobolPreferenceUIPlugin.getResource("%COLLSEQ_LABEL"));
		radioCSLOCALE = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%LOCALE_LABEL"));
		radioCSEBCDIC = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%EBCDIC_VALUE"));		
		radioCSBIN = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%BIN_VALUE"));		
		return;
	}	

	private void createNCOLLSEQGroup(Composite parent) {
		Composite group = createGroup(parent, 2, CobolPreferenceUIPlugin.getResource("%NCOLLSEQ_LABEL"));
		radioNCSLOCALE = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%LOCALE_LABEL"));		
		radioNCSBIN = createRadioButton(group, CobolPreferenceUIPlugin.getResource("%BIN_VALUE"));		
		return;
	}	

	private void createFileExtensionTable(Composite parent) {
		GridData data = new GridData();
		GridLayout layout = new GridLayout();
		
		Composite composite = new Composite(parent, SWT.NULL);
		layout.numColumns = 2;
		composite.setLayout(layout);
		composite.setLayoutData(GridUtil.createFill());
		
		createFileExtensionTableViewer(composite);
		
		Composite btnGroup = new Composite(composite, SWT.NULL);
		layout = new GridLayout();
		layout.numColumns = 1;
		layout.marginHeight=15;
		btnGroup.setLayout(layout);
		btnGroup.setLayoutData(GridUtil.createVerticalFill());
				
		_editBtn = new Button(btnGroup, SWT.PUSH);
		_editBtn.setText(CobolPreferenceUIPlugin.getResource("%EDIT_BUTTON"));
		_editBtn.setLayoutData(GridUtil.createHorizontalFill());
		_editBtn.setEnabled(false);
		
		_editBtn.addSelectionListener(this);
		tableViewer.getTable().addSelectionListener(this);	
	}
	

	/**
	 * @param main
	 */
	private void createFileExtensionTableViewer(Composite parent) {
		// Create the table viewer.
		tableViewer =
			new TableViewer(
				parent,
				SWT.BORDER | SWT.SINGLE | SWT.FULL_SELECTION | SWT.HIDE_SELECTION);		

		// Create the table control.
		Table table = tableViewer.getTable();
		table.setHeaderVisible(true);
		table.setLinesVisible(true);
		GridData data = createFill();
		data.heightHint = 50;
		table.setLayoutData(data);

		TableLayout tableLayout = new TableLayout();
		CellEditor[] cellEditors = new CellEditor[COLUMNS.length];

		TableColumn stringColumn = new TableColumn(table, SWT.LEFT);
		stringColumn.setText(CobolPreferenceUIPlugin.getResource("%EXTENSION_COLUMN_LABEL"));
		tableLayout.addColumnData(new ColumnWeightData(60));
		cellEditors[0] = new TextCellEditor(table);

		TableColumn comboColumn = new TableColumn(table, SWT.LEFT);
		comboColumn.setText(CobolPreferenceUIPlugin.getResource("%EXTENSION_SUPPORT_LABEL"));
		tableLayout.addColumnData(new ColumnWeightData(40));

		cellEditors[1] = new ComboBoxCellEditor(table, VALUES);

		table.setLayout(tableLayout);

		// Adjust the table viewer.
		tableViewer.setColumnProperties(COLUMNS);
		tableViewer.setContentProvider(new PreferenceContentProvider());
		tableViewer.setLabelProvider(new PreferenceLabelProvider());
		tableViewer.setCellModifier(new PreferenceCellModifier(tableViewer));
		tableViewer.setCellEditors(cellEditors);	
	}	

	/**
	 * Creates a grid data object that occupies vertical and horizontal
	 * space.
	 */
	public GridData createFill() {
		GridData gd= new GridData();
		gd.horizontalAlignment= GridData.FILL;
		gd.grabExcessHorizontalSpace= true;
		gd.verticalAlignment= GridData.FILL;
		gd.grabExcessVerticalSpace= true;
		return gd;
	}
	
	private void disableAllButtons() {
		radioEBig.setSelection (false);
		radioELittle.setSelection (false);
		radioRIEBig.setSelection (false);
		radioRIELittle.setSelection (false);
		radioASCII.setSelection (false);
		radioEBCDIC.setSelection (false);
		radioEBCDICC.setSelection (false);
		radioCOSTD.setSelection (false);
		radioCOOPT.setSelection (false);
		radioCOBIN.setSelection (false);
		//radioNPPFD.setSelection (false);
		//radioNPNOPFD.setSelection (false);
		//radioNPMIG.setSelection (false);
		radioNSDBCS.setSelection (false);
		radioNSNATIONAL.setSelection (false);
		radioASINGLE.setSelection (false);
		radioADOUBLE.setSelection (false);
		radioCSBIN.setSelection (false);
		radioCSEBCDIC.setSelection (false);
		radioCSLOCALE.setSelection (false);
		radioNCSBIN.setSelection (false);
		radioNCSLOCALE.setSelection (false);		
	}

	/**
	 * Returns the key for a value in the map
	 */
	private Object getKey(java.util.Map map, Object value) {
		for (java.util.Iterator i = map.keySet().iterator(); i.hasNext();) {
			Object o = i.next();
			if (map.get(o).equals(value))
				return o;
		}
		return null;
	}

	public Vector getValidationErrorMessages() {
	
		/*
		 * Validate any fields on the screen
		 * and return an vector of error messages
		 * If the screen is valid, the vector will be empty (size = 0)
		 */
		Vector errorMessages = new Vector();
		
		/*
		 * Test the codepage by trying to convert a byte array
		 * to a String using the specifed codepage
		 * If it fails, the codepage is invalid
		 */	
		try
		{
			com.ibm.etools.cobol.importer.CobolTypeUtilities.validateCodepage(textCP.getText());	
			if (!(textHostCP.getText().equals("")))
				com.ibm.etools.cobol.importer.CobolTypeUtilities.validateCodepage(textHostCP.getText());
			com.ibm.etools.cobol.importer.CobolTypeUtilities.validateCurrency(textCurrency.getText());
		}
		catch (Exception ex)
		{
			errorMessages.add(ex.getMessage());			
		}
	
		return errorMessages;
	}

	
	public HashMap getValues() {

		HashMap propertyMap = new HashMap();		
		//store the values of the property Map
		propertyMap.put(PRE_COBOL_PLATFORM_SELECTION, (Object) new Integer(comboPS.getSelectionIndex()));

		propertyMap.put(PRE_COBOL_CODEPAGE, textCP.getText());

		propertyMap.put(PRE_COBOL_FLOATING_POINT_FORMAT, (Object) new Integer(comboFPF.getSelectionIndex()));

		// store ENDIAN
		if (radioEBig.getSelection()) {
			propertyMap.put(PRE_COBOL_ENDIAN, (String)endian_values.get(radioEBig));
		} else {
			propertyMap.put(PRE_COBOL_ENDIAN, (String)endian_values.get(radioELittle));
		}
		
		// store REMOTE ENDIAN
		if (radioRIEBig.getSelection()) {
			propertyMap.put(PRE_COBOL_REMOTE_ENDIAN, (String)remote_int_endian_values.get(radioRIEBig));
		} else {
			propertyMap.put(PRE_COBOL_REMOTE_ENDIAN, (String)remote_int_endian_values.get(radioRIELittle));
		}
	
		// store EXT_DECIMAL_SIGN
		if (radioASCII.getSelection()) {
			propertyMap.put(PRE_COBOL_EXT_DECIMAL_SIGN, (String)extra_decimal_sign_values.get(radioASCII));
		} else if (radioEBCDIC.getSelection()) {
			propertyMap.put(PRE_COBOL_EXT_DECIMAL_SIGN, (String)extra_decimal_sign_values.get(radioEBCDIC));
		} else {
			propertyMap.put(PRE_COBOL_EXT_DECIMAL_SIGN, (String)extra_decimal_sign_values.get(radioEBCDICC));
			propertyMap.put(PRE_COBOL_HOST_CODEPAGE_EC, textHostCP.getText());
		}

		// store COMPILER TIME LOCALE		
		propertyMap.put(PRE_COBOL_COMPILE_TIME_LOCALE, (Object) new Integer(comboLC.getSelectionIndex()));
		
		// store ASCII CODEPAGE	
		propertyMap.put(PRE_COBOL_ASCII_CODEPAGE, (Object) new Integer(comboACP.getSelectionIndex()));

		// store ERROR MESSAGES LANGUAGE
		propertyMap.put(PRE_COBOL_ERROR_MSGS_LANG, (Object) new Integer(comboEL.getSelectionIndex()));

		// store CURRENCY
		propertyMap.put(PRE_COBOL_CURRENCY, (String) (textCurrency.getText()));		
		
		// store SOSI
		propertyMap.put(PRE_COBOL_SOSI, (Object) new Boolean(checkBoxSOSI.getSelection()));		
		
		// store trunc
		if (radioCOSTD.getSelection()) {
			propertyMap.put(PRE_COBOL_TRUNC, (String)trunc_values.get(radioCOSTD));
		} else if (radioCOOPT.getSelection()) {
			propertyMap.put(PRE_COBOL_TRUNC, (String)trunc_values.get(radioCOOPT));
		} else {
			propertyMap.put(PRE_COBOL_TRUNC, (String)trunc_values.get(radioCOBIN));
		}

        // no display in UI for NUMPROC, use default value
        propertyMap.put(PRE_COBOL_NUMPROC, NUMPROC_PFD);

		// store nsymbol
		if (radioNSDBCS.getSelection()) {
			propertyMap.put(PRE_COBOL_NSYMBOL, (String)nsymbol_values.get(radioNSDBCS));
		} else {
			propertyMap.put(PRE_COBOL_NSYMBOL, (String)nsymbol_values.get(radioNSNATIONAL));
		}
				
		// store QUOTE
		if (radioASINGLE.getSelection()) {
			propertyMap.put(PRE_COBOL_QUOTE, (String)quote_values.get(radioASINGLE));
		} else {
			propertyMap.put(PRE_COBOL_QUOTE, (String)quote_values.get(radioADOUBLE));
		}
		
		// store collseq
		if (radioCSBIN.getSelection()) {
			propertyMap.put(PRE_COBOL_COLLSEQ, (String)collseq_values.get(radioCSBIN));
		} else if (radioCSEBCDIC.getSelection()) {
			propertyMap.put(PRE_COBOL_COLLSEQ, (String)collseq_values.get(radioCSEBCDIC));
		} else {
			propertyMap.put(PRE_COBOL_COLLSEQ, (String)collseq_values.get(radioCSLOCALE));
		}

		// store ncollseq
		if (radioNCSBIN.getSelection()) {
			propertyMap.put(PRE_COBOL_NCOLLSEQ, (String)ncollseq_values.get(radioNCSBIN));
		} else {
			propertyMap.put(PRE_COBOL_NCOLLSEQ, (String)ncollseq_values.get(radioNCSLOCALE));
		}

		// store file extension support values
		MyTableElement[] myTableElements = (MyTableElement[]) tableViewer.getInput();
		if (myTableElements != null){
			for (int i=0; i < myTableElements.length; ++i){
				if (myTableElements[i].getText().equals(".cbl"))
					propertyMap.put(PRE_COBOL_EXTENSION_CBL, getExtenstionSupportIndex(myTableElements[i].getValue()));
				else if (myTableElements[i].getText().equals(".ccp"))
					propertyMap.put(PRE_COBOL_EXTENSION_CCP, getExtenstionSupportIndex(myTableElements[i].getValue()));
				else if (myTableElements[i].getText().equals(".cob"))
					propertyMap.put(PRE_COBOL_EXTENSION_COB, getExtenstionSupportIndex(myTableElements[i].getValue()));
				else if (myTableElements[i].getText().equals(".cpy"))
					propertyMap.put(PRE_COBOL_EXTENSION_CPY, getExtenstionSupportIndex(myTableElements[i].getValue()));			
			}
		}
		return propertyMap;
	}

	private void initializePreferenceStoreValues() {
	
		// Initialized the values that will be stored in the preference storage
		floating_pt_values.add(FLOAT_IEEE);
		floating_pt_values.add(FLOAT_IBM390);
	
		platform_selection_values.add(PLATFORM_WIN);
		platform_selection_values.add(PLATFORM_AIX);
		platform_selection_values.add(PLATFORM_ZOS);
		platform_selection_values.add(PLATFORM_NONE);
	
		endian_values.put(radioEBig, ENDIAN_BIG);
		endian_values.put(radioELittle, ENDIAN_LITTLE);	
		
		remote_int_endian_values.put(radioRIEBig, ENDIAN_BIG);
		remote_int_endian_values.put(radioRIELittle, ENDIAN_LITTLE);	
			
		extra_decimal_sign_values.put(radioASCII, DECIMAL_ASCII);
		extra_decimal_sign_values.put(radioEBCDIC, DECIMAL_EBCDIC);
		extra_decimal_sign_values.put(radioEBCDICC, DECIMAL_EBCDICC);
		
		quote_values.put(radioADOUBLE, QUOTE_DOUBLE);
		quote_values.put(radioASINGLE, QUOTE_SINGLE);
		
		trunc_values.put(radioCOSTD, TRUNC_STD);
		trunc_values.put(radioCOOPT, TRUNC_OPT);
		trunc_values.put(radioCOBIN, TRUNC_BIN);			
		
		nsymbol_values.put(radioNSDBCS, NSYMBOL_DBCS);
		nsymbol_values.put(radioNSNATIONAL, NSYMBOL_NATIONAL);	

		collseq_values.put(radioCSLOCALE, COLLSEQ_LOCALE);
		collseq_values.put(radioCSEBCDIC, COLLSEQ_EBCDIC);
		collseq_values.put(radioCSBIN, COLLSEQ_BIN);		

		ncollseq_values.put(radioNCSLOCALE, NCOLLSEQ_LOCALE);
		ncollseq_values.put(radioNCSBIN, NCOLLSEQ_BIN);		
	}
	
	/**
	 * Insert the method's description here.
	 * Creation date: (7/27/2001 10:02:21 AM)
	 *
	 * Initializes states of the controls from the preference store.
	 */
	protected void initializeValues() {
		
		int iLimit = 0;
	
		// populate platform selection combo box
		iLimit = PS_ITEM.length - 1;
		for(int ix=0; ix < PS_ITEM.length; ix++){
			comboPS.add(PS_ITEM[ix]);
		}
	
		// populate floating point format combo box
		iLimit = FPF_ITEM.length - 1;
		for(int ix=0; ix < FPF_ITEM.length; ix++){
			comboFPF.add(FPF_ITEM[ix]);
		}

		//populate compile time locale name, ascii codepages, error messages language combo boxs
		Vector v = clrc.getLocaleNames();
		Enumeration enum = v.elements();
		while(enum.hasMoreElements()){
			comboLC.add((String)enum.nextElement());
		}
		v = clrc.getErrorMessagesLanguage();
		enum = v.elements();
		while(enum.hasMoreElements()){
			comboEL.add((String)enum.nextElement());
		}		
		
		setValuesFromMap(CobolPreferenceStore.getValues());
		
		comboPS.setFocus();
	}

	/**
	 * Insert the method's description here.
	 * Creation date: (7/27/2001 10:02:21 AM)
	 *
	 * Sets the states of the controls from values in a hashmap.
	 */
	public void setValuesFromMap(HashMap map) {
		
		String work;
		int iValue = 0;
		boolean bValue = false;
		Vector workVector = new Vector();
	
		disableAllButtons();
		
		// set platform selection
		if(map.containsKey(PRE_COBOL_PLATFORM_SELECTION)){
			iValue = ((Integer)map.get(PRE_COBOL_PLATFORM_SELECTION)).intValue();
			comboPS.setText(comboPS.getItem(iValue));		
		}
	
		// set codepage
		work = (String)map.get(PRE_COBOL_CODEPAGE);
		if(work != null){
			textCP.setText(work);
		}
			
		// set FPF
		if(map.containsKey(PRE_COBOL_FLOATING_POINT_FORMAT)){
			iValue = ((Integer)map.get(PRE_COBOL_FLOATING_POINT_FORMAT)).intValue();
			comboFPF.setText(comboFPF.getItem(iValue));
		}
	
		// set ENDIAN
		work = (String)map.get(PRE_COBOL_ENDIAN);
		if(work != null){
			Button b = (Button)getKey(endian_values, work);	
			if (b != null)
				b.setSelection (true);
		}
	
		// set REMOTE ENDIAN
		work = (String)map.get(PRE_COBOL_REMOTE_ENDIAN);
		if(work != null){
			Button b = (Button)getKey(remote_int_endian_values, work);	
			if (b != null)
				b.setSelection (true);
		}
	
		// set EXT_DECIMAL_SIGN
		work = (String)map.get(PRE_COBOL_EXT_DECIMAL_SIGN);
		if(work != null){
			Button b = (Button)getKey(extra_decimal_sign_values, work);	
			if (b != null) {
				b.setSelection (true);
				// set host codepage for external decimals (ebcdic Custom)
				hostCodePageValue = (String)map.get(PRE_COBOL_HOST_CODEPAGE_EC);
				workOnHostCodePageSection(b);
			}
		}
		
		// set COMPILE TIME LOCALE selection
		if(map.containsKey(PRE_COBOL_COMPILE_TIME_LOCALE)){
			iValue = ((Integer)map.get(PRE_COBOL_COMPILE_TIME_LOCALE)).intValue();						
			comboLC.setText(comboLC.getItem(iValue));		
		}		

		// set ASCII CODEPAGE
		if(map.containsKey(PRE_COBOL_ASCII_CODEPAGE)){
			iValue = ((Integer)map.get(PRE_COBOL_ASCII_CODEPAGE)).intValue();
			Vector v = clrc.getASCIICodePages(comboLC.getText());
			Enumeration enum = v.elements();
			comboACP.removeAll();
			while(enum.hasMoreElements()){
				comboACP.add((String)enum.nextElement());
			}
			comboACP.setText(comboACP.getItem(iValue));
		}
		
		// set ERROR MESSAGES LANGUAGE
		if(map.containsKey(PRE_COBOL_ERROR_MSGS_LANG)){
			iValue = ((Integer)map.get(PRE_COBOL_ERROR_MSGS_LANG)).intValue();
			comboEL.setText(comboEL.getItem(iValue));		
		}		

		// set CURRENCY
		work = (String)map.get(PRE_COBOL_CURRENCY);
		if(work != null){
			textCurrency.setText(work);
		}
		
		
		// set SOSI
		if(map.containsKey(PRE_COBOL_SOSI)){
			bValue = ((Boolean)map.get(PRE_COBOL_SOSI)).booleanValue();
		    checkBoxSOSI.setSelection(bValue);		
		}
		
		// set trunc
		work = (String)map.get(PRE_COBOL_TRUNC);
		if(work != null){
			Button b = (Button)getKey(trunc_values, work);	
			if (b != null)
				b.setSelection (true);
		}
		// set nsymbol
		work = (String)map.get(PRE_COBOL_NSYMBOL);
		if(work != null){
			Button b = (Button)getKey(nsymbol_values, work);	
			if (b != null)
				b.setSelection (true);
		}
		
		// set QUOTE
		work = (String)map.get(PRE_COBOL_QUOTE);
		if(work != null){
			Button b = (Button)getKey(quote_values, work);	
			if (b != null)
				b.setSelection (true);
		}
	
		
		// set nsymbol
		work = (String)map.get(PRE_COBOL_NSYMBOL);
		if(work != null){
			Button b = (Button)getKey(nsymbol_values, work);	
			if (b != null)
				b.setSelection (true);
		}
		
		// set collseq
		work = (String)map.get(PRE_COBOL_COLLSEQ);
		if(work != null){
			Button b = (Button)getKey(collseq_values, work);	
			if (b != null)
				b.setSelection (true);
		}
		
		// set ncollseq
		work = (String)map.get(PRE_COBOL_NCOLLSEQ);
		if(work != null){
			Button b = (Button)getKey(ncollseq_values, work);	
			if (b != null)
				b.setSelection (true);
		}

		// set file extension (CBL) support
		work = (String)map.get(PRE_COBOL_EXTENSION_CBL);
		if(work != null){
			workVector.add(new MyTableElement(".cbl", getExtenstionSupportValue(work)));						
		}						
		// set file extension (CCP) support
		work = (String)map.get(PRE_COBOL_EXTENSION_CCP);
		if(work != null){
			workVector.add(new MyTableElement(".ccp", getExtenstionSupportValue(work)));						
		}
		// set file extension (COB) support
		work = (String)map.get(PRE_COBOL_EXTENSION_COB);
		if(work != null){
			workVector.add(new MyTableElement(".cob", getExtenstionSupportValue(work)));						
		}
		// set file extension (CPY) support
		work = (String)map.get(PRE_COBOL_EXTENSION_CPY);
		if(work != null){
			workVector.add(new MyTableElement(".cpy", getExtenstionSupportValue(work)));						
		}
		
		// set extension support table
		loadDataIntoTable(workVector);
	}

	/**
	 * @param value
	 * @return
	 */
	private String getExtenstionSupportValue(String text) {
		if (text.equals(ICobolPreferenceConstants.DEFAULT_ES))
			return CobolPreferenceUIPlugin.getResource("%EXTENSION_SUPPORT_VALUE1");
		return CobolPreferenceUIPlugin.getResource("%EXTENSION_SUPPORT_VALUE2");
	}

	/**
	 * @param value
	 * @return
	 */
	private String getExtenstionSupportIndex(String value) {
		if (value.equals(CobolPreferenceUIPlugin.getResource("%EXTENSION_SUPPORT_VALUE1")))
			return ICobolPreferenceConstants.DEFAULT_ES;
		return ICobolPreferenceConstants.NOT_DEFAULT_ES;
	}
	
	
	/**
	 * Handle a UI scripting event.
	 *
	 * print all events to the System console
	 */
	public void widgetSelected(SelectionEvent e)
	{
		String work;

		parentPage.setErrorMessage(null);

		// compare @source
		Object source = e.getSource();
		
		if (source == tableViewer.getTable()) {
			enableButtons();
			return;
		} else if (source == _editBtn){
			int idx = tableViewer.getTable().getSelectionIndex();
			if (idx != -1) {
				CBETableElement sel =(CBETableElement) tableViewer.getElementAt(idx);
	
				String extension = sel.getText();
				String support = sel.getValue();
	
				showEditDialog(CobolPreferenceUIPlugin.getResource("%EDIT_FILE_EXTENSION_SUPPORT"),extension,support);
			}
			return;
		} else if (source == buttonCPSelect) {
			selectCP(textCP);
		} else if (source == buttonHostCPSelect) {
			selectCP(textHostCP);
		} else if (source == comboPS) {
			this.resetPlatformSelection();		
		} else if (source == comboLC) {
			this.resetAsciiCodepages();
		} else {
			workOnHostCodePageSection(source);	
		}
		if (parentPage instanceof WizardPage) {
			((CobolImporterPropertiesPage)parentPage).validatePage();
		}
	}

	/**
	 * @param source
	 */
	private void workOnHostCodePageSection(Object source) {
		if (source == radioASCII || source == radioEBCDIC) {
			if (!(textHostCP.getText().equals(""))) {
				hostCodePageValue = textHostCP.getText();
				textHostCP.setText("");			
			}
			textHostCP.setEnabled(false);
			buttonHostCPSelect.setEnabled(false);
		} else if (source == radioEBCDICC){
			textHostCP.setEnabled(true);
			textHostCP.setText(hostCodePageValue);				
			buttonHostCPSelect.setEnabled(true);				
		}			
	}

	public void widgetDefaultSelected(SelectionEvent e) {
	}

	public void modifyText(ModifyEvent e) {
		// if they have modified the codepage - make sure it is valid.
		if (e.getSource() == textCP || e.getSource() == textHostCP || e.getSource() == textCurrency) {
			if (parentPage instanceof CobolPreferencePage) {
				((CobolPreferencePage) parentPage).validate();
			} else if (parentPage instanceof WizardPage) {
				((CobolImporterPropertiesPage)parentPage).validatePage();
			}
		}
	}

	/**
	 * Insert the method's description here.
	 * Creation date: (7/27/2001 10:02:21 AM)
	 */
	public void performDefaults() {
		setValuesFromMap(CobolPreferenceStore.getDefaultValues());
		hostCodePageValue = OS_CODEPAGE;
		parentPage.setErrorMessage(null);
		comboPS.setFocus();	
	}
	
	private void resetPlatformSelection() {
	String work;
	int iValue = 0;
	
		if (comboPS.getSelectionIndex() >= 0)	
			iValue = comboPS.getSelectionIndex();	
		else
			iValue = DEFAULT_PS;
			
		switch (iValue) {
			
			// Win32
			case 0:
				textCP.setText(DEFAULT_CODEPAGE);
				comboFPF.setText(comboFPF.getItem(DEFAULT_FPT));
				radioEBig.setSelection (false);
				radioELittle.setSelection (true);
				radioRIEBig.setSelection (false);
				radioRIELittle.setSelection (true);
				radioASCII.setSelection (true);
				radioEBCDIC.setSelection (false);
				radioEBCDICC.setSelection (false);
				checkBoxSOSI.setSelection(false);
				radioCSBIN.setSelection(true);
				radioCSEBCDIC.setSelection(false);
				radioCSLOCALE.setSelection(false);
				radioNCSBIN.setSelection(true);
				radioNCSLOCALE.setSelection(false);
				break;
			// AIX
			case 1:
				textCP.setText(DEFAULT_CODEPAGE);
				comboFPF.setText(comboFPF.getItem(DEFAULT_FPT));
				radioEBig.setSelection (true);
				radioELittle.setSelection (false);
				radioRIEBig.setSelection (true);
				radioRIELittle.setSelection (false);
				radioASCII.setSelection (true);
				radioEBCDIC.setSelection (false);
				radioEBCDICC.setSelection (false);
				checkBoxSOSI.setSelection(false);
				radioCSBIN.setSelection(true);
				radioCSEBCDIC.setSelection(false);
				radioCSLOCALE.setSelection(false);
				radioNCSBIN.setSelection(true);
				radioNCSLOCALE.setSelection(false);				
				break;
			// z/OS
			case 2:
				textCP.setText(OS_CODEPAGE);
				comboFPF.setText(comboFPF.getItem(OS_FPT));
				radioEBig.setSelection (true);
				radioELittle.setSelection (false);
				radioRIEBig.setSelection (true);
				radioRIELittle.setSelection (false);
				radioASCII.setSelection (false);
				radioEBCDIC.setSelection (true);
				radioEBCDICC.setSelection (false);
				checkBoxSOSI.setSelection(true);
				radioCSBIN.setSelection(false);
				radioCSEBCDIC.setSelection(true);
				radioCSLOCALE.setSelection(false);
				radioNCSBIN.setSelection(true);
				radioNCSLOCALE.setSelection(false);				
				break;
			// Not Specified
			// Leave all selections unchanged
			case 3:
				break;
		}
	}

	/**
	 * 
	 */
	private void resetAsciiCodepages() {		
		if (comboLC.getSelectionIndex() > -1) {
			String localeName = comboLC.getText();
			Vector v = clrc.getASCIICodePages(localeName);
			Enumeration enum = v.elements();
			comboACP.removeAll();
			while(enum.hasMoreElements()){
				comboACP.add((String)enum.nextElement());
			}
			if (comboACP.getSelectionIndex() == -1)
				comboACP.select(0);
		}				
	}	
	
	/**
	 * Code page selection helper
	 */
	private void selectCP(Text textButton) {
		CobolCodePageSelectionDialog ccpsd = new CobolCodePageSelectionDialog(
								new Shell(), textButton.getText() );
		int rtnBtn = ccpsd.open();
		if(rtnBtn == CobolCodePageSelectionDialog.OK)	{
			textButton.setText((String) ccpsd.getSelectedObject());
			if (textButton == textHostCP)
				hostCodePageValue = textButton.getText();
		}
	}

	private void loadDataIntoTable(Vector v) {
		tableElements = initializeTable(v);
		tableViewer.setInput(tableElements);
	}

	private MyTableElement[] initializeTable(Vector v) {
		MyTableElement[] tableElements = new MyTableElement[v.size()];
		return (MyTableElement[]) v.toArray(tableElements);		
	}	


	public Text getTextCurrency() {
		return textCurrency;
	}	

	private void showEditDialog(
			String title,
			String extension,
			String support) {

			EditDialog dialog =	new EditDialog(main.getShell(), title, extension, support);
			dialog.open();

			if (dialog.getReturnCode() == Window.OK) {
				int idx = tableViewer.getTable().getSelectionIndex();
				if (idx!=-1) {
					CBETableElement tableElem = (CBETableElement)(tableViewer.getElementAt(idx));
					tableElem.setValue(dialog.support());
					tableElem.setUserModified(true);
					tableViewer.update(tableElem,null);
				}
			}
		}

	private void enableButtons() {
		int selection = tableViewer.getTable().getSelectionIndex();
		_editBtn.setEnabled(tableViewer.getTable().getItemCount() > 0 && selection != -1);
	}

	public void setHelpContextIds() {
		
		/*CONTEXT_ID pcob0010 for COBOL Preference Page */
		WorkbenchHelp.setHelp(parentPage.getControl(), HelpContextIds.COBOL_PP_PREFERENCEPAGE);
	
		/*CONTEXT_ID pcob0015 for Platform Selection */
		WorkbenchHelp.setHelp(comboPS, HelpContextIds.COBOL_PP_PLATFORM_SELECTION);
	
		/*CONTEXT_ID pcob0020 for COBOL Preference Page */
		WorkbenchHelp.setHelp(textCP, HelpContextIds.COBOL_PP_CODEPAGE);
	
		/*CONTEXT_ID pcob0030 for COBOL Preference Page */
		WorkbenchHelp.setHelp(comboFPF, HelpContextIds.COBOL_PP_FLOATING_POINT_FORMAT);
	
		/*CONTEXT_ID pcob0040 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioEBig, HelpContextIds.COBOL_PP_ENDIAN_BIG);
		
		/*CONTEXT_ID pcob0050 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioELittle, HelpContextIds.COBOL_PP_ENDIAN_LITTLE);
	
		/*CONTEXT_ID pcob0060 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioRIEBig, HelpContextIds.COBOL_PP_REMOTE_ENDIAN_BIG);
	
		/*CONTEXT_ID pcob0070 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioRIELittle, HelpContextIds.COBOL_PP_REMOTE_ENDIAN_LITTLE);
	
		/*CONTEXT_ID pcob0080 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioASCII, HelpContextIds.COBOL_PP_EXT_DECIMAL_SIGN_ASCII);
	
		/*CONTEXT_ID pcob0090 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioEBCDIC, HelpContextIds.COBOL_PP_EXT_DECIMAL_SIGN_EDBCDIC);
	
		/*CONTEXT_ID pcob0100 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioEBCDICC, HelpContextIds.COBOL_PP_EXT_DECIMAL_SIGN_CEDBCDIC);
	
		/*CONTEXT_ID pcob0110 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioCOSTD, HelpContextIds.COBOL_PP_TRUNC_STD);
	
		/*CONTEXT_ID pcob0120 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioCOOPT, HelpContextIds.COBOL_PP_TRUNC_OPT);
	
		/*CONTEXT_ID pcob0130 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioCOBIN, HelpContextIds.COBOL_PP_TRUNC_BIN);
	
		/*CONTEXT_ID pcob0170 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioNSDBCS, HelpContextIds.COBOL_PP_NSYMBOL_DBCS);
	
		/*CONTEXT_ID pcob0180 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioNSNATIONAL, HelpContextIds.COBOL_PP_NSYMBOL_NATIONAL);
	
		/*CONTEXT_ID pcob0190 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioADOUBLE, HelpContextIds.COBOL_PP_QUOTE_DOUBLE);
	
		/*CONTEXT_ID pcob0200 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioASINGLE, HelpContextIds.COBOL_PP_QUOTE_SINGLE);

		/*CONTEXT_ID pcob0210 for COBOL Preference Page */
		WorkbenchHelp.setHelp(comboLC, HelpContextIds.COBOL_PP_COMPILE_TIME_LOCALE);

		/*CONTEXT_ID pcob0220 for COBOL Preference Page */
		//WorkbenchHelp.setHelp(comboACP, HelpContextIds.COBOL_PP_ASCII_CODEPAGE);
		/* Same context help as in for COMPILE TIME LOCALE */
		WorkbenchHelp.setHelp(comboACP, HelpContextIds.COBOL_PP_COMPILE_TIME_LOCALE);

		/*CONTEXT_ID pcob0230 for COBOL Preference Page */
		WorkbenchHelp.setHelp(comboEL, HelpContextIds.COBOL_PP_ERROR_MSGS_LANG);

		/*CONTEXT_ID pcob0240 for COBOL Preference Page */
		WorkbenchHelp.setHelp(textCurrency, HelpContextIds.COBOL_PP_CURRENCY);

		/*CONTEXT_ID pcob0250 for COBOL Preference Page */
		WorkbenchHelp.setHelp(checkBoxSOSI, HelpContextIds.COBOL_PP_SOSI);

		/*CONTEXT_ID pcob0260 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioCSLOCALE, HelpContextIds.COBOL_PP_COLLSEQ_LOCALE);

		/*CONTEXT_ID pcob0270 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioCSEBCDIC, HelpContextIds.COBOL_PP_COLLSEQ_EBCDIC);

		/*CONTEXT_ID pcob0280 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioCSBIN, HelpContextIds.COBOL_PP_COLLSEQ_BIN);

		/*CONTEXT_ID pcob0290 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioNCSLOCALE, HelpContextIds.COBOL_PP_NCOLLSEQ_LOCALE);

		/*CONTEXT_ID pcob0300 for COBOL Preference Page */
		WorkbenchHelp.setHelp(radioNCSBIN, HelpContextIds.COBOL_PP_NCOLLSEQ_BIN);

		/*CONTEXT_ID pcob0310 for COBOL Preference Page */
		WorkbenchHelp.setHelp(tableViewer.getTable(), HelpContextIds.COBOL_PP_FILE_EXTENSION_SUPPORT);
		
	}

}
