// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<PART NUMBER - 5724-B75>>
//   (C) Copyright IBM Corp. 2001, 2003 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************

package com.ibm.etools.marshall.runtime;

import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Plugin;

/**
 * The main plugin class to be used in the desktop.
 */
public class MarshallRuntimePlugin extends Plugin
{
	private static final String copyright = "Licensed Material - Property of IBM <<PART NUMBER - 5724-D15>> (C) Copyright IBM Corp. 2001, 2003 - All Rights Reserved. US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.".intern(); //$NON-NLS-1$

	public static final String PLUGIN_NAME = "PLUGIN_NAME";
	public static final String PLUGIN_DESC = "PLUGIN_DESC";

	//The shared instance.
	private static MarshallRuntimePlugin plugin;
	//Resource bundle.
	private ResourceBundle resourceBundle;

	/**
	 * The constructor.
	 */
	public MarshallRuntimePlugin()
	{
		super();
		plugin = this;
	}

	/**
	 * Returns the shared instance.
	 */
	public static MarshallRuntimePlugin getDefault()
	{
		return plugin;
	}

	/**
	 * Returns the string from the plugin's resource bundle,
	 * or 'key' if not found.
	 */
	public static String getResourceString (String key)
	{
		ResourceBundle bundle = MarshallRuntimePlugin.getDefault().getResourceBundle();
		try
		{
			return bundle.getString(key);
		}
		catch (MissingResourceException e)
		{
			return key;
		}
	}

	/**
	 * Returns the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle()
	{
		if (resourceBundle == null)
		{
			try
			{
				resourceBundle = Platform.getResourceBundle (getBundle());
			}
			catch (MissingResourceException exc)
			{
				resourceBundle = null;
			}
		}

		return (resourceBundle);
	}

	/**
	 * Returns a resource string mapping to the specifed resource key.
	 * @param key The resource key to retrieve.
	 * @exception MissingResourceException The requested resource string does not exist.
	 */
	
	public final String getString (String key) throws MissingResourceException
	{
	   return (getResourceString(key));
	}
	/**
	 * Returns a resource string mapping to the specifed resource key, and replacement
	 * arguments.
	 * @param key The resource key to retrieve.
	 * @param arg The replacement arguments.
	 * @exception MissingResourceException The requested resource string does not exist.
	 */
	
	public final String getString (String key, Object arg[]) throws MissingResourceException
	{
	   String basemsgfmt = getResourceString(key);
	   MessageFormat msgfmt = new MessageFormat(basemsgfmt);
	
	   return (msgfmt.format(arg));
	}
	/**
	 * Returns a resource string mapping to the specifed resource key, and replacement
	 * argument.
	 * @param key The resource key to retrieve.
	 * @param arg1 The replacement argument.
	 * @exception MissingResourceException The requested resource string does not exist.
	 */
	
	public final String getString (String key, String arg1) throws MissingResourceException
	{
	   if (arg1 != null)
	   {
	      Object msgobj[] = new Object[1];
	      msgobj[0] = arg1;
	      return (getString(key, msgobj));
	   }
	   else
	      return (getString(key));
	}
	/**
	 * Returns a resource string mapping to the specifed resource key, and replacement
	 * arguments.
	 * @param key The resource key to retrieve.
	 * @param arg1 The first replacement argument.
	 * @param arg2 The second replacement argument.
	 * @exception MissingResourceException The requested resource string does not exist.
	 */
	
	public final String getString(String key, String arg1, String arg2) throws MissingResourceException
	{
	   if ((arg1 != null) && (arg2 != null))
	   {
	      Object msgobj[] = new Object[2];
	      msgobj[0] = arg1;
	      msgobj[1] = arg2;
	      return (getString(key, msgobj));
	   }
	   else
	      return (getString(key));
	}
	/**
	 * Returns a resource string mapping to the specifed resource key, and replacement
	 * arguments.
	 * @param key The resource key to retrieve.
	 * @param arg1 The first replacement argument.
	 * @param arg2 The second replacement argument.
	 * @param arg3 The third replacement argument.
	 * @exception MissingResourceException The requested resource string does not exist.
	 */
	
	public final String getString(String key, String arg1, String arg2, String arg3) throws
	   MissingResourceException
	{
	   if ((arg1 != null) && (arg2 != null) && (arg3 != null))
	   {
	      Object msgobj[] = new Object[3];
	      msgobj[0] = arg1;
	      msgobj[1] = arg2;
	      msgobj[2] = arg3;
	      return (getString(key, msgobj));
	   }
	   else
	      return (getString(key));
	}
}